#!/bin/sh
set -e
set -x

if [ "$#" -ne 3 ]; then
    echo 'Need domain name and mail and old server.'
    false
fi
domain="$1"
mail="$2"
old_server="$3"

# Install configs, set up firewall.
config_tree_prefix="${HOME}/config/buster"
./install_for_target.sh web dumpsite
./copy_dirtree.sh "${config_tree_prefix}/etc_files" "" web dumpsite
nft -f /etc/nftables.conf

# Set up letsencrypt certificate. TODO: Is it auto-renewed?
ln -sf /etc/nginx/sites-available/default /etc/nginx/sites-enabled/default
certbot --nginx --agree-tos --redirect --no-eff-email -m "${mail}" -d "${domain}"
rm /etc/nginx/sites-enabled/default

# Set up dump dirs.
mkdir /var/www-dump
chown plom:plom /var/www-dump
dump_dir=dump
geheim_dir=geheim
su -lc "mkdir ${dump_dir} ${geheim_dir}" plom
su -lc "ln -s /home/plom/${dump_dir} /var/www-dump/${dump_dir}" plom
su -lc "ln -s /home/plom/${geheim_dir} /var/www-dump/${geheim_dir}" plom
password_geheim=$(pwgen -1)
echo "foo:{PLAIN}${password_geheim}" > /var/www-dump/password_geheim
echo "geheim password is: ${password_geheim}"

# Set up redo.
wget http://news.dieweltistgarnichtso.net/bin/archives/redo-sh.tar.gz
tar -moxzf redo-sh.tar.gz -C /usr/local

# Set up connection to old dump server.
cp "${config_tree_prefix}/setup_scripts/prepare_to_meet_server.sh" /home/plom/
chown plom:plom /home/plom/prepare_to_meet_server.sh
su -lc "./prepare_to_meet_server.sh ${old_server}" plom
read -p'Hit Enter when you are done.' ignore
rm /home/plom/prepare_to_meet_server.sh

# Set up zettel.
su -lc "git clone --mirror ${old_server}:zettel.git" plom
cp "${config_tree_prefix}/other_files/zettel_hook_post-receive" /home/plom/zettel.git/hooks/post-receive
su -lc "git clone ~/zettel.git && cd zettel && redo" plom
su -lc "ln -s /home/plom/zettel /var/www-dump/zettel" plom

# Set up redo blog.
su -lc "git clone --mirror ${old_server}:blog.git" plom
cp "${config_tree_prefix}/other_files/blog_hook_post-receive" /home/plom/blog.git/hooks/post-receive
su -lc "git clone ~/blog.git" plom
# FIXME: we should not depend on a GitHub repo
su -lc "git clone https://github.com/plomlompom/redo-blog.git" plom
su -lc "cd redo-blog && ./add_dir.sh ~/blog" plom
su -lc "cd blog && redo" plom
su -lc "ln -s /home/plom/blog/public /var/www-dump/blog" plom

# Prepare NGINX.
sed -i "s/REPLACE_fqdn_ECALPER/${domain}/g" /etc/nginx/sites-available/dumpsite.nginx
ln -s /etc/nginx/sites-available/dumpsite.nginx /etc/nginx/sites-enabled/dumpsite.nginx

service nginx restart
